@@ -28,7 +28,7 @@ def largest_errors(func, X, y, profile_columns, n=25):
     pred = func(X).to_numpy()
 
     df = (
-        X.copy()
+        X[profile_columns]
         .assign(y=y, pred=pred)  # to numpy is needed to help time inference
         .astype({"y": float, "pred": float})  # account for boolean output/predictions
         .assign(Delta=lambda x: np.abs(x["y"] - x["pred"]))
@@ -42,7 +42,6 @@ def largest_errors(func, X, y, profile_columns, n=25):
     first = ["Predicted Value", "Actual Value", "Delta"]
     last = [x for x in cols if x not in first]
     df = df.reindex(columns=first + last)
-    df = df[profile_columns]
 
     return df_to_json_table(df, date_format="iso", date_unit="s", double_precision=2)
 
