@@ -58,7 +58,7 @@ def varimp(func, X, y, profile_columns, metric="Rmse", n_max=10000, feat_max=25)
         .mark_bar()
         .encode(
             x="Relative Importance",
-            y=alt.Y("Variable", sort=None, axis=alt.Axis(labelLimit=500), title=""),
+            y=alt.Y("Variable", sort=None),
             tooltip=[
                 alt.Tooltip("Variable"),
                 alt.Tooltip("Relative Importance:Q", format=".2f"),
