@@ -37,29 +37,74 @@ class Explainer(ABC):
         raise NotImplementedError
 
 
+def update_columns(base, update):
+    """Update a base dataframe column-wise with a replacement dataframe
+
+    Parameters
+    ----------
+    base : pd.DataFrame
+        Base dataframe that will be updated
+    update : pd.DataFrame
+        Values to use when updating
+
+    Returns
+    -------
+    pd.DataFrame
+        Updated DataFrame where base-columns have been replaced with update-columns
+    """
+    base_columns = base.columns
+    base = base.drop(columns=update.columns)
+    if (len(base) == 1) & (len(update) > 1):  # numpy-style broadcasting
+        base = pd.concat([base] * len(update), axis=0, ignore_index=True)
+    base.index = update.index.copy()
+    combined = pd.concat([base, update], axis=1)
+    return combined.reindex(columns=base_columns)
+
+
+def reduce_func(func, X):
+    """Reduce a function to accept an arbitrary subset of X as input
+
+    Parameters
+    ----------
+    func : function
+        Original function, must accept X as input
+    X : pd.DataFrame
+        Original dataframe, used for filling in missing columns
+
+    Returns
+    -------
+    function
+        Reduced function that takes an arbitrary subset of X's columns as input
+    """
+
+    def func_subset(X_subset, X, original_func):
+        X_updated = update_columns(base=X, update=X_subset)
+        return original_func(X_updated)
+
+    reduced_func = partial(func_subset, X=X, original_func=func)
+    return reduced_func
+
+
 class ShapExplainer(Explainer):
     def __init__(self, func, X, profile_columns=None):
-        if profile_columns is None:
-            profile_columns = X.columns
+        """Create a Shap Explainer
 
-        if len(X.columns) > len(profile_columns):
+        Parameters
+        ----------
+        func : function
+            Function to be explained. Must map from X to array-like
+        X : pd.DataFrame
+            Background dataset for Shapley value calculation
+        profile_columns : list, optional
+            Calculate Shapley values only for a subset of columns, by default all columns will be included
+        """
+        if profile_columns is not None:
+            func = reduce_func(func, X=self._create_background_data(X))
+            X = X[profile_columns]
 
-            def func_fused(X_profile_columns, X_background):
-                X_combined = X_profile_columns.copy()
-                for col in X_background.columns:
-                    X_combined[col] = X_background[col].iloc[[0]]
-                X_combined = X_combined.reindex(columns=X.columns)
-                return func(X_combined)
-
-            X_background = self._create_background_data(X.drop(columns=profile_columns))
-            self.func = partial(func_fused, X_background=X_background)
-            self.X = self._create_background_data(X[profile_columns])
-            self.n_col = len(profile_columns)
-
-        else:
-            self.func = func
-            self.X = self._create_background_data(X)
-            self.n_col = len(X.columns)
+        self.func = func
+        self.X = self._create_background_data(X)
+        self.n_col = len(self.X.columns)
 
     @staticmethod
     def _create_background_data(X):
