@@ -113,11 +113,3 @@ def vega_sanitize(var, datatype=None):
     if datatype:
         var = var + ":" + datatype
     return var
-
-
-def df_to_serializable_dict(series):
-    """Transform numpy types that can't be serialized to ones that can"""
-    return {
-        key: val.item() if isinstance(val, np.generic) else val
-        for key, val in series.replace({np.nan: None, np.inf: None}).to_dict().items()
-    }
