@@ -1,9 +1,9 @@
 import shutil
-from datetime import date, datetime
 from pathlib import Path
 
 import numpy as np
 import pandas as pd
+import pytest
 from tktl import Tktl
 
 from profiling.convenience import (
@@ -13,6 +13,7 @@ from profiling.convenience import (
     create_expectations,
     create_importance,
 )
+from profiling.utils import vega_sanitize
 
 # Generate test data
 X = pd.DataFrame.from_dict(
@@ -27,6 +28,7 @@ X = pd.DataFrame.from_dict(
         ),
     }
 )
+X_unsanitized = X.rename(columns={col: col + ".Var-[Brackets]" for col in X.columns})
 y_regression = pd.Series([5, 3.2, -0.2], name="Outcome")
 y_binary = pd.Series([True, False, True], name="Outcome")
 
@@ -50,10 +52,16 @@ def type_sensitive(df):
     return np.random.uniform(size=len(df))
 
 
+@tktl.endpoint(kind="binary", X=X_unsanitized, y=y_binary)
+def unsanitized(X):
+    return np.random.uniform(size=len(X))
+
+
 def test_expectations():
     for endpoint in tktl.endpoints:
         name = endpoint.func.__name__
         create_expectations(endpoint)
+        X, _ = endpoint.get_input_and_output_for_profiling()
         for var in X.columns:
             path = Path(BASE_RESULTS_PATH, name, "anatomy", "condexp", var + ".json")
             assert path.exists()
@@ -64,6 +72,7 @@ def test_dependence():
     for endpoint in tktl.endpoints:
         name = endpoint.func.__name__
         create_dependence(endpoint)
+        X, _ = endpoint.get_input_and_output_for_profiling()
         for var in X.columns:
             path = Path(BASE_RESULTS_PATH, name, "anatomy", "partialdep", var + ".json")
             assert path.exists()
@@ -86,3 +95,12 @@ def test_accuracy():
         assert Path(BASE_RESULTS_PATH, name, "accuracy", "metrics.json").exists()
         assert Path(BASE_RESULTS_PATH, name, "accuracy", "errors.json").exists()
     shutil.rmtree(BASE_RESULTS_PATH)
+
+
+@pytest.mark.parametrize(
+    "var,expected",
+    [(".", r"\."), ("[", r"\["), ("Var.Unsanitized[1]-.", r"Var\.Unsanitized\[1\]-\.")],
+)
+def test_sanitize(var, expected):
+    var_sanitized = vega_sanitize(var)
+    assert var_sanitized == expected
